@@ -5,7 +5,7 @@ class activity(base):
     def __init__(self, token):
         super().__init__(token)
 
-    def getTopicList(self, activityId, order=1, onlyShowImg=0, page=1, row=20):
+    def getTopicList(self, activityId, order=1, onlyShowImg=0, page=1, rows=20):
         api_name = "activity/getTopicList"
         data = {}
         data["activityId"] = activityId
@@ -13,7 +13,7 @@ class activity(base):
         data["order"] = order
         data["page"] = page
         data["rows"] = rows
-        return self.request(api_name)
+        return self.request(api_name, params=data)
 
     def addLike(self, activityId, floor, replyId):
         api_name = "activity/activityLikeOper"
@@ -21,4 +21,4 @@ class activity(base):
         data["activityId"] = activityId
         data["floor"] = floor
         data["replyId"] = replyId
-        return self.request(api_name)
+        return self.request(api_name, method="POST", json=data)
