@@ -19,7 +19,7 @@ def get_up_token(cjdg_access_token):
     logger.error(params)
 
 
-def request_accesstoken(acc: str, pwd: str, safe=False, domain=False, **kwargs) -> str:
+def request_accesstoken(acc: str, pwd: str, safe=False, domain=True, **kwargs) -> str:
     # 请求accesstooke函数
     protocol = "https" if safe else "http"
     domain_name = "bms.chaojidaogou.com" if domain else "it.xxynet.com"
@@ -34,7 +34,7 @@ def request_accesstoken(acc: str, pwd: str, safe=False, domain=False, **kwargs)
         return accessToken
 
 
-def request_accesstoken_pc(acc: str, pwd: str, safe=False, domain=False, **kwargs) -> str:
+def request_accesstoken_pc(acc: str, pwd: str, safe=False, domain=True, **kwargs) -> str:
     # 请求accesstooke函数
     protocol = "https" if safe else "http"
     domain_name = "bms.chaojidaogou.com" if domain else "it.xxynet.com"
@@ -60,7 +60,7 @@ class base:
         self.token = token
         self.app_secret = app_secret
 
-    def request(self, api_name=None, method="GET",url=None, api_prefix="api/", safe=False, domain=False,**kwargs):
+    def request(self, api_name=None, method="GET",url=None, api_prefix="api/", safe=False, domain=True,**kwargs):
         protocol = "https" if safe else "http"
         domain_name = "bms.chaojidaogou.com" if domain else "it.xxynet.com"
         host_name = f"{protocol}://{domain_name}/shopguide/"
@@ -103,7 +103,7 @@ class baseT:
         self.token = token
         self.app_secret = app_secret
 
-    def request(self, api_name=None, method="GET", url=None, api_prefix="api/", safe=False, domain=False, convert=False, **kwargs):
+    def request(self, api_name=None, method="GET", url=None, api_prefix="api/", safe=False, domain=True, convert=False, **kwargs):
         protocol = "https" if safe else "http"
         domain_name = "bms.chaojidaogou.com" if domain else "it.xxynet.com"
         host_name = f"{protocol}://{domain_name}/"
@@ -147,7 +147,7 @@ class baseSub:
         self.token = token
         self.app_secret = app_secret
 
-    def request(self, api_name=None, method="GET", url=None, api_prefix="api/", safe=False, domain=False, convert=False, **kwargs):
+    def request(self, api_name=None, method="GET", url=None, api_prefix="api/", safe=False, domain=True, convert=False, **kwargs):
         protocol = "https" if safe else "http"
         domain_name = "sub.chaojidaogou.com" if domain else "it.xxynet.com"
         host_name = f"{protocol}://{domain_name}/"
@@ -191,7 +191,7 @@ class baseCient:
         self.token = token
         self.app_secret = app_secret
 
-    def request(self, api_name=None, method="GET", url=None, api_prefix="api/", safe=False, domain=False, **kwargs):
+    def request(self, api_name=None, method="GET", url=None, api_prefix="api/", safe=False, domain=True, **kwargs):
         protocol = "https" if safe else "http"
         domain_name = "cient.chaojidaogou.com" if domain else "it.xxynet.com"
         host_name = f"{protocol}://{domain_name}/"
@@ -237,7 +237,7 @@ class baseApi:
         self.token = token
         self.app_secret = app_secret
 
-    def request(self, api_name=None, method="GET", url=None, api_prefix="api/", safe=False, domain=False, **kwargs):
+    def request(self, api_name=None, method="GET", url=None, api_prefix="api/", safe=False, domain=True, **kwargs):
         protocol = "https" if safe else "http"
         domain_name = "api.chaojidaogou.com" if domain else "it.xxynet.com"
         host_name = f"{protocol}://{domain_name}/"
