@@ -1,5 +1,6 @@
 import requests
-from .base import base
+# from .base import base
+from cjdg_open_api.base import base
 
 
 class user(base):
